@@ -14,6 +14,7 @@ use NewsExtractor::SiteSpecificExtractor::www_allnews_tw;
 use NewsExtractor::SiteSpecificExtractor::www_peopo_org;
 use NewsExtractor::SiteSpecificExtractor::www_ntdtv_com;
 use NewsExtractor::SiteSpecificExtractor::www_ksnews_com_tw;
+use NewsExtractor::SiteSpecificExtractor::news_tvbs_com_tw;
 
 has extractor => (
     required => 0,
@@ -36,6 +37,7 @@ use constant {
         'www.peopo.org' => 'NewsExtractor::SiteSpecificExtractor::www_peopo_org',
         'www.ntdtv.com' => 'NewsExtractor::SiteSpecificExtractor::www_ntdtv_com',
         'www.ksnews.com.tw' => 'NewsExtractor::SiteSpecificExtractor::www_ksnews_com_tw',
+        'news.tvbs.com.tw' => 'NewsExtractor::SiteSpecificExtractor::news_tvbs_com_tw',
     },
     CSSRuleSetByHost => {
         'www.nownews.com' => {
